// -*- C++ -*-
//    Title: imagegray.h
//  Created: Tue Oct 16 19:00:50 2001
//   Author: Tim Weyrich <weyrich@inf.ethz.ch>
//
// copyright (c) 2001--2003, Computer Graphics Laboratory, ETH Zuerich
//

#ifndef __IMAGEGRAY_H__
#define __IMAGEGRAY_H__

//! C-struct that holds a gray-level image.
/*! Use imageGrayNew() and imageGrayFree() to create or to delete an
 *  ImageGray struct, respectively.
 */
typedef struct
{
  int    width;                 //!< Width of the image.
  int    height;                //!< Height of the image.

  int    bytesPerPixel;         //!< Number of bytes per Pixel (always 1).
  
  //! Pixel data of the image.
  /*! The data is organized in row-major order. That is, pixels of an
   *  image row are stored subsequently from left to right, and rows
   *  are stored subsequently from top to bottom.
   */
  unsigned char  *data;
} ImageGray;


//! Creates a new gray-level image.
extern ImageGray  *imageGrayNew(int width, int height);

//! Deletes a gray-level image.
extern void        imageGrayFree(ImageGray *img);


//! Creates a copy of a gray-level image.
extern ImageGray  *imageGrayClone(const ImageGray *img);


//! Clears a gray-level image.
extern void        imageGrayClear(ImageGray *img);

//! Sets all pixels in the image to a given value.
extern void        imageGraySet(ImageGray *img, unsigned val);

//! Reads a gray-level image from a TIFF file.
extern ImageGray  *imageGrayReadTIFF(const char *fname);

//! Writes a gray-level image as a TIFF file.
extern int         imageGrayWriteTIFF(const char *fname, const ImageGray *img);

//! Draws a line into a gray-level image.
/*! The line is drawn with pixels of gray-value \a grayValue from the
 *  point (\a x0, \a y0) to (\a x1, \a y1).
 */
extern void  imageGrayDrawLine(ImageGray *img, int x0, int y0, int x1, int y1, unsigned char grayValue);

//! Draws a line into a gray-level image by inverting pixels.
/*! The line is drawn from the point (\a x0, \a y0) to (\a x1, \a y1).
 */
extern void  imageGrayInvertLine(ImageGray *img, int x0, int y0, int x1, int y1);

#endif
